==> zio-aws-elasticache_2.12-5.17.103.1-sources.jar: zio/aws/elasticache/model/SlotMigration.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class SlotMigration(progressPercentage: Option[Double] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.SlotMigration = {
    import SlotMigration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.SlotMigration
      .builder()
      .optionallyWith(progressPercentage.map(value => value: java.lang.Double))(
        _.progressPercentage
      )
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.SlotMigration.ReadOnly =
    zio.aws.elasticache.model.SlotMigration.wrap(buildAwsValue())
}
object SlotMigration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.SlotMigration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.SlotMigration =
      zio.aws.elasticache.model
        .SlotMigration(progressPercentage.map(value => value))
    def progressPercentage: Option[Double]
    def getProgressPercentage: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("progressPercentage", progressPercentage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.SlotMigration
  ) extends zio.aws.elasticache.model.SlotMigration.ReadOnly {
    override val progressPercentage: Option[Double] =
      scala.Option(impl.progressPercentage()).map(value => value: Double)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.SlotMigration
  ): zio.aws.elasticache.model.SlotMigration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_2.12-5.20.22.3-sources.jar: zio/aws/elasticache/model/SlotMigration.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SlotMigration(
    progressPercentage: Optional[Double] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.SlotMigration = {
    import SlotMigration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.SlotMigration
      .builder()
      .optionallyWith(progressPercentage.map(value => value: java.lang.Double))(
        _.progressPercentage
      )
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.SlotMigration.ReadOnly =
    zio.aws.elasticache.model.SlotMigration.wrap(buildAwsValue())
}
object SlotMigration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.SlotMigration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.SlotMigration =
      zio.aws.elasticache.model
        .SlotMigration(progressPercentage.map(value => value))
    def progressPercentage: Optional[Double]
    def getProgressPercentage: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("progressPercentage", progressPercentage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.SlotMigration
  ) extends zio.aws.elasticache.model.SlotMigration.ReadOnly {
    override val progressPercentage: Optional[Double] = zio.aws.core.internal
      .optionalFromNullable(impl.progressPercentage())
      .map(value => value: Double)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.SlotMigration
  ): zio.aws.elasticache.model.SlotMigration.ReadOnly = new Wrapper(impl)
}
